Software Heritage - graph service
=================================

Tooling and services, collectively known as ``swh-graph``, providing fast
access to the graph representation of the `Software Heritage
<https://www.softwareheritage.org/>`_
`archive <https://archive.softwareheritage.org/>`_.  The service is in-memory,
based on a compressed representation of the Software Heritage Merkle DAG.


Bibliography
------------

In addition to accompanying technical documentation, ``swh-graph`` is also
described in the following scientific papers. If you use ``swh-graph`` for your
research work, please acknowledge it by citing:

.. note::

  Paolo Boldi, Antoine Pietri, Sebastiano Vigna, Stefano Zacchiroli.
  `Ultra-Large-Scale Repository Analysis via Graph Compression
  <https://ieeexplore.ieee.org/document/9054827>`_. In proceedings of `SANER
  2020 <https://saner2020.csd.uwo.ca/>`_: The 27th IEEE International
  Conference on Software Analysis, Evolution and Reengineering, pages
  184-194. IEEE 2020.

  Links: `preprint <https://upsilon.cc/~zack/research/publications/saner-2020-swh-graph.pdf>`__,
  `bibtex <https://upsilon.cc/~zack/research/publications/saner-2020-swh-graph.bib>`__.

  Tommaso Fontana, Sebastiano Vigna, Stefano Zacchiroli.
  `WebGraph: The Next Generation (Is in Rust) <https://dl.acm.org/doi/abs/10.1145/3589335.3651581>`_.
  In proceedings of `WWW'24 <https://www2024.thewebconf.org/>`_:
  The ACM Web Conference 2024. Pages 686-689. ACM 2024.

  Links: `preprint <https://hal.science/hal-04494627/>`__,
  `bibtex <https://dblp.dagstuhl.de/rec/conf/www/FontanaVZ24.bib?param=1>`__.
